// generated by CommonLibrary.cmake, do not edit.

/**
 * @file include/GLStats/version.h
 * Defines version macros and class for library GLStats.
 */

#ifndef GLSTATS_VERSION_H
#define GLSTATS_VERSION_H

#include <GLStats/api.h>
#include <string>

namespace GLStats
{
    /** The current major version. */
#   define GLSTATS_VERSION_MAJOR 0

    /** The current minor version. */
#   define GLSTATS_VERSION_MINOR 3

    /** The current patch level. */
#   define GLSTATS_VERSION_PATCH 2

    /** The current SCM revision. */
#   define GLSTATS_VERSION_REVISION 0x0

    /** The current binary interface. */
#   define GLSTATS_VERSION_ABI 1ull

    /** The current major.minor.version as a string. */
#   define GLSTATS_VERSION_STRING \
    "0.3.2"

    /** The current major.minor.version.revision as a string. */
#   define GLSTATS_REV_STRING \
    "0.3.2.0x0"

/** True if the current version is newer than the given one. */
#   define GLSTATS_VERSION_GT( MAJOR, MINOR, PATCH )       \
    ( (GLSTATS_VERSION_MAJOR>MAJOR) ||                     \
      (GLSTATS_VERSION_MAJOR==MAJOR && (GLSTATS_VERSION_MINOR>MINOR || \
          (GLSTATS_VERSION_MINOR==MINOR && GLSTATS_VERSION_PATCH>PATCH))))

/** True if the current version is equal or newer to the given. */
#   define GLSTATS_VERSION_GE( MAJOR, MINOR, PATCH )       \
    ( (GLSTATS_VERSION_MAJOR>MAJOR) ||                     \
      (GLSTATS_VERSION_MAJOR==MAJOR && (GLSTATS_VERSION_MINOR>MINOR || \
          (GLSTATS_VERSION_MINOR==MINOR && GLSTATS_VERSION_PATCH>=PATCH))))

/** True if the current version is older than the given one. */
#   define GLSTATS_VERSION_LT( MAJOR, MINOR, PATCH )       \
    ( (GLSTATS_VERSION_MAJOR<MAJOR) ||                     \
      (GLSTATS_VERSION_MAJOR==MAJOR && (GLSTATS_VERSION_MINOR<MINOR || \
          (GLSTATS_VERSION_MINOR==MINOR && GLSTATS_VERSION_PATCH<PATCH))))

/** True if the current version is older or equal to the given. */
#   define GLSTATS_VERSION_LE( MAJOR, MINOR, PATCH )       \
    ( (GLSTATS_VERSION_MAJOR<MAJOR) ||                     \
      (GLSTATS_VERSION_MAJOR==MAJOR && (GLSTATS_VERSION_MINOR<MINOR || \
        (GLSTATS_VERSION_MINOR==MINOR && GLSTATS_VERSION_PATCH<=PATCH))))

/** Information about the current GLStats version. */
class GLSTATS_API Version
{
public:
    /** @return the current major version of GLStats. */
    static int getMajor();

    /** @return the current minor version of GLStats. */
    static int getMinor();

    /** @return the current patch level of GLStats. */
    static int getPatch();

    /** @return the current GLStats version (MM.mm.pp). */
    static std::string getString();

    /** @return the SCM revision. */
    static unsigned long long getRevision();

    /** @return the current binary interface version of GLStats. */
    static int getABI();

    /** @return the current GLStats version plus the git SHA hash (MM.mm.pp.rev). */
    static std::string getRevString();

    /**
     * Runtime check for ABI compatibility.
     *
     * Call from code using GLStats. Will fail if the executable
     * was compiled against a version incompatible with the runtime version.
     *
     * @return true if the link-time and compile-time DSO are compatible.
     */
    static bool check()
    {
        return getMajor()==GLSTATS_VERSION_MAJOR &&
               getMinor()==GLSTATS_VERSION_MINOR;
    }

    /** @return JSON schema describing this object. */
    static std::string getSchema()
    {
        return R"(
                {
                  "title": "Version",
                  "type": "object",
                  "description": "Version information of the running application",
                  "properties": {
                    "major": { "type": "integer" },
                    "minor": { "type": "integer" },
                    "patch": { "type": "integer" },
                    "abi": { "type": "integer" },
                    "revision": { "type": "string" }
                  }
               }
               )";
    }

    /** @return JSON-encoded data for this object. */
    static std::string toJSON()
    {
        return R"(
               {
                 "major": 0,
                 "minor": 3,
                 "patch": 2,
                 "abi": 1,
                 "revision": "0"
               }
               )";
    }
};

}

#endif
